﻿using System;
using System.Collections.Generic;
using System.Globalization;
using TSLab.Script.Handlers;
using TSLab.Script.Helpers;

namespace RusAlgo.Handlers.Public.Adaptive
{
    [HandlerCategory("RusAlgo")]
    [HandlerName("Adaptive MACD")]
    [InputInfo(0, "Данные")]
    [InputInfo(1, "Период быстрой")]
    [InputInfo(1, "Период медленной")]
    public class AMacd : IThreeSourcesHandler, IDoubleInputs, IDoubleReturns, IStreamHandler, IContextUses
    {
        public IContext Context { set; private get; }

        public IList<double> Execute(IList<double> price, IList<double> fastPeriod, IList<double> slowPeriod)
        {
            var values = new double[Context.BarsCount];

            for (var i = 0; i < Context.BarsCount; i++)
            {
                var currFastPeriod = Math.Max(Convert.ToInt32(fastPeriod[i]), 1);
                var currSlowPeriod = Math.Max(Convert.ToInt32(slowPeriod[i]), 1);

                var fastValue = Context.GetData("AdaptiveMacdRusAlgo",
                                                new[]
                                                    {
                                                        currFastPeriod.ToString(CultureInfo.InvariantCulture),
                                                        price.GetHashCode().ToString(CultureInfo.InvariantCulture)
                                                    },
                                                () => Series.EMA(price, currFastPeriod));

                var slowValue = Context.GetData("AdaptiveMacdRusAlgo",
                                                new[]
                                                    {
                                                        currSlowPeriod.ToString(CultureInfo.InvariantCulture),
                                                        price.GetHashCode().ToString(CultureInfo.InvariantCulture)
                                                    },
                                                () => Series.EMA(price, currSlowPeriod));
                
                values[i] = fastValue[i] - slowValue[i];
            }

            return values;
        }
    }
}