﻿using System;
using System.Collections.Generic;
using System.Globalization;
using TSLab.DataSource;
using TSLab.Script;
using System.Linq;
using TSLab.Script.Handlers;

namespace RusAlgo.Handlers.Public
{
    /// <summary>
    /// Вспомогательный класс, содержащий хелпер методы. В том числе и методы расширения.
    /// </summary>
    public static class TradeHelper
    {
        #region Общие хелперы

        public static bool IsNull(this object obj)
        {
            return obj == null;
        }

        /// <summary>
        /// Метод упрощающий форматирование строк.
        /// </summary>
        /// <param name="str">Строка для форматирования.</param>
        /// <param name="args">Аргументы для форматирования.</param>
        /// <returns></returns>
        public static string Put(this string str, params object[] args)
        {
            // Вводим культуру для того чтобы double числа не переводились как числа с запятой! Это гадит.
            return string.Format(CultureInfo.InvariantCulture, str, args);
        }

        /// <summary>
        /// Выводит в лог информационное сообщение.
        /// </summary>
        /// <param name="ctx"></param>
        /// <param name="str"></param>
        /// <param name="args"></param>
        public static void LogInfo(this IContext ctx, string str, params object[] args)
        {
            // Задаем цвет соообщения
            var color = System.Drawing.Color.Blue;
            
            // Формируем строку, вставляем спец слово Info.
            var msg = string.Format("Info: " + str, args);
            
            ctx.Log(msg, new Color(color.ToArgb()));
        }

        /// <summary>
        /// Выводит в лог сообщение об ошибке.
        /// </summary>
        /// <param name="ctx"></param>
        /// <param name="str"></param>
        /// <param name="args"></param>
        public static void LogError(this IContext ctx, string str, params object[] args)
        {
            // Задаем цвет соообщения
            var color = System.Drawing.Color.Red;

            // Формируем строку, вставляем спец слово Info.
            var msg = string.Format("Error: " + str, args);

            ctx.Log(msg, new Color(color.ToArgb()));
        }

        #endregion

        #region Базовые типы данных

        /// <summary>
        /// Определяет является ли число бесконечностью
        /// </summary>
        /// <param name="d"></param>
        /// <returns></returns>
        public static bool IsInfinity(this double d)
        {
            return double.IsInfinity(d);
        }

        /// <summary>
        /// Определяет является ли значение НЕ ЧИСЛОМ, то есть неопределенностью
        /// </summary>
        /// <param name="d"></param>
        /// <returns></returns>
        public static bool IsNaN(this double d)
        {
            return double.IsNaN(d);
        }

        /// <summary>
        /// Четное ли число?
        /// </summary>
        /// <param name="i"></param>
        /// <returns></returns>
        public static bool IsEven(this int i)
        {
            return i%2 == 0;
        }

        /// <summary>
        /// НЕчетное ли число?
        /// </summary>
        /// <param name="i"></param>
        /// <returns></returns>
        public static bool IsOdd(this int i)
        {
            return i%2 != 0;
        }

        #endregion
    }
}
